@@ -12,5 +12,5 @@ class ListConectividadeView(View):
         device = Device.objects.all()
 
         return render(request, 'conectividadeapp/listagem.html', {
-            'Device': device,
+            'device': device,
         })
